@@ -16,7 +16,7 @@ class Orchestrator:
 
     def __init__(self, queue_mapping: Dict[str, str], concurrency: int, cloud_provider_config: Dict[str, str]) -> None:
         self.cloud_provider_config = cloud_provider_config
-        self._check_queue_mapping(queue_mapping)
+        self._check_queue_mapping(queue_mapping, cloud_provider_config)
         self.queue_mapping = queue_mapping
         self.concurrency = concurrency
         self.internal_queue: Queue = Queue()
@@ -27,12 +27,14 @@ class Orchestrator:
         self._initialize_workers()
         self._register_shutdown_signals()
 
-    def _check_queue_mapping(self, queue_mapping: Dict[str, str]) -> None:
+    def _check_queue_mapping(self, queue_mapping: Dict[str, str], cloud_provider_config: Dict[str, str]) -> None:
         """
         Check if queue urls specified in queue_mapping dict by user exist for the cloud provider.
         :param queue_mapping: Dict which contain relation between queue urls and methods to execute.
         :type queue_mapping: dict
         """
+        if cloud_provider_config.get("skip_queue_mapping_verification"):
+            return
         client = get_client(self.cloud_provider_config)
         queue_urls = client.list_queues().get("QueueUrls", [])
         for key in queue_mapping:
