@@ -1,6 +1,7 @@
 from typing import Optional, Dict, Union
-from .errors import ConfigError
+from .validators import CloudQueueWorkerValidator
 from .orchestrator import Orchestrator
+from .logging import logger
 
 
 class CloudQueueWorker:
@@ -14,7 +15,7 @@ class CloudQueueWorker:
         self.concurrency = concurrency
         self.cloud_provider_config = cloud_provider_config
 
-    def update_config(self, config: Optional[Dict[str, Union[str, int]]]) -> None:
+    def update_config(self, config: Dict[str, Union[str, int]]) -> None:
         """
         Update CloudQueueWorker object after initialization using a dict.
         :param config: dict to use to update CloudQueueWorker object
@@ -29,14 +30,8 @@ class CloudQueueWorker:
         Method to start CloudQueueWorker
         :return: None
         """
-        if self.queue_mapping is None:
-            raise ConfigError("queue_mapping parameter is missing in the config")
+        logger.info("Start cloud queue worker")
 
-        if self.concurrency is None:
-            raise ConfigError("concurrency parameter is missing in the config")
-
-        if self.cloud_provider_config is None:
-            raise ConfigError("cloud_provider_config parameter is missing in the config. Valid values: aws, azure, gcp")
-
-        orchestrator = Orchestrator(**self.__dict__)
+        cloud_queue_worker_validator = CloudQueueWorkerValidator().load(self.__dict__)
+        orchestrator = Orchestrator(**CloudQueueWorkerValidator().dump(cloud_queue_worker_validator))
         orchestrator.run()
