@@ -14,5 +14,5 @@ def get_client(config: Dict[str, str]):
         aws_access_key_id=config.get("aws_access_key_id"),
         aws_secret_access_key=config.get("aws_secret_access_key"),
         region_name=config["region_name"],
-        endpoint_url="https://sqs.{}.amazonaws.com".format(config["region_name"])
+        endpoint_url=config.get("endpoint_url", "https://sqs.{}.amazonaws.com".format(config["region_name"])),
     )
